@@ -809,7 +809,7 @@ def remove_ad(client, customer_id, ad_group_id, criterion_id):
 
     print(f"Removed ad {ad_group_ad_response.results[0].resource_name}.")
 
-def get_search_term_report(client, customer_id,start_date='2022-01-01', end_date='2022-01-10'):
+def get_search_term_report(client, customer_id,start_date='2022-01-01', end_date='2022-01-10', full=False):
     df_dict = {
     'date' : list(),
     'stv_resource_name' : list(),
@@ -873,7 +873,10 @@ def get_search_term_report(client, customer_id,start_date='2022-01-01', end_date
         FROM search_term_view
         WHERE campaign.status IN ('ENABLED','PAUSED') AND
         """
-        query2 = f" segments.date >= '{str(start)[0:10]}' AND segments.date < '{str(start+step)[0:10]}'"
+        if full: 
+            query2 = f" segments.date >= '{str(start)[0:10]}' AND segments.date < '{str(end)[0:10]}'"
+        else:
+            query2 = f" segments.date >= '{str(start)[0:10]}' AND segments.date < '{str(start+step)[0:10]}'"
         query = query1 + '\n' + query2
         search_request = client.get_type("SearchGoogleAdsStreamRequest")
         search_request.customer_id = customer_id
@@ -916,6 +919,8 @@ def get_search_term_report(client, customer_id,start_date='2022-01-01', end_date
                 df_dict['metrics_avg_cpc'].append(metrics.average_cpc)
                 df_dict['metrics_impressions'].append(metrics.impressions)
                 df_dict['metrics_interactions'].append(metrics.interactions)
+        if full:
+            break
         start += step
     df = pd.DataFrame.from_dict(df_dict)
     return df
